/* DefaultGraphInvariantListModel.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2007 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.list;

import java.net.URI;

/**
 * Default implementation of {@link GraphInvariantListModel}.
 */
public class DefaultGraphInvariantListModel implements GraphInvariantListModel {
    
    //
    private GraphListModel graphListModel;
    
    //
    private InvariantListModel invariantListModel;
    
    //
    public DefaultGraphInvariantListModel() {
        this(new DefaultGraphListModel(), new DefaultInvariantListModel());
    }
    
    //
    public DefaultGraphInvariantListModel(GraphListModel graphListModel)  {
        this(graphListModel, new DefaultInvariantListModel());
    }
    
    //
    public DefaultGraphInvariantListModel(InvariantListModel invariantListModel) {
        this(new DefaultGraphListModel(), invariantListModel);
    }
    
    //
    public DefaultGraphInvariantListModel(GraphListModel graphListModel, InvariantListModel invariantListModel) {
        this.graphListModel = graphListModel;
        this.invariantListModel = invariantListModel;
    }
    
    //
    public GraphListModel getGraphListModel() {
        return graphListModel;
    }
    
    //
    public InvariantListModel getInvariantListModel(){
        return invariantListModel;
    }
    
    //
    public GraphList getGraphList() {
        return graphListModel;
    }
    
    //
    public InvariantList getInvariantList() {
        return invariantListModel;
    }
    
    //
    public void setName(String name) {
        graphListModel.setName(name);
    }
    
    //
    public String getName() {
        return graphListModel.getName();
    }
    
    //
    public URI getURI() {
        return graphListModel.getURI();
    }
    
    //
    public void setURI(URI uri) {
        graphListModel.setURI(uri);
    }
    
}
