/* InvariantValueTableCellRenderer.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2007 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.list;

import be.ugent.caagt.jmathtex.TeXConstants;
import be.ugent.caagt.jmathtex.TeXFormula;

import javax.swing.table.DefaultTableCellRenderer;

import org.grinvin.invariants.InvariantValue;

/**
 * Table cell renderer for objects of type {@link InvariantValue}.
 */
public class InvariantValueTableCellRenderer extends DefaultTableCellRenderer {
    
    /** Default constructor */
    public InvariantValueTableCellRenderer() {
    }

    /**
     * Renders an invariant value.
     */
    @Override public void setValue(Object value) {
        setIcon(null);
        setText("");
        if (value instanceof InvariantValue) {
            InvariantValue iv = (InvariantValue)value;
            if (Double.isInfinite(iv.asDouble()))
                setIcon(new TeXFormula().addSymbol("infty").createTeXIcon(TeXConstants.STYLE_DISPLAY, getFont().getSize()+2));
            else
                setText(iv.toText());
        } else if (value != null)
            throw new IllegalArgumentException
                    ("InvariantValueTableCellRenderer can only be used with columns of type InvariantValue");
    }
    
}
