/* CloseGraph.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2007 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.list.commands;

import be.ugent.caagt.swirl.commands.AttributedCommandManager;
import org.grinvin.list.GraphPropertiesWindow;
import org.pietschy.command.ActionCommand;
import org.pietschy.command.CommandManager;

/**
 * Command to close the current GraphPropertiesWindow.
 */
public class CloseGraph extends ActionCommand {
    
    //
    private static final String KEY = GraphPropertiesWindow.class.getName();
    
    /**
     * Panel onto which this command acts.
     */
    private GraphPropertiesWindow window;
       
    /**
     * Construct an action command of this type.
     * @param manager Command manager, which must be of class {@link AttributedCommandManager}
     */
    public CloseGraph(CommandManager manager, String id) {
        super (manager, id);
        this.window = (GraphPropertiesWindow)((AttributedCommandManager)manager).getAttribute (KEY);
    }

    // implements handleExecute
    public void handleExecute() {
        // get rid of the window, we will recreate it if necessary
        window.dispose();
    }
    
}
